*******************************************************************************
*                           Calibration: Step 1                               *
*******************************************************************************

*********************Option****************************************************
*Option: if ad valorem tariffs are used in the model, delete the star to
*activate the line $setglobal tariffadvalorem
*Option: if specific tariffs are used in the model, delete the star to activate
*the line $setglobal tariffspecific

*$setglobal tariffadvalorem YES
$setglobal tariffspecific YES
*******************************************************************************


*** Definition of parameters used to activate the different options
Parameter advalorem parameter used to activate the option ad valorem tariffs ;
advalorem = 0;
$if setglobal tariffadvalorem advalorem=1 ;

Parameter specific  parameter used to activate the option specific tariffs ;
specific = 0;
$if setglobal tariffspecific specific=1 ;

***Sets definition
SET i trading countries
/
KEN     Kenya
TZA     Tanzania
UGA     Uganda
ZMB     Zambia
ZWE     Zimbabwe
/;

alias (i,j,jj) ;

***Parameters declaration
Parameters
*Net trade parameters
                 trade01(i,j)           Initial matrix of trade from i to j (in tons)
$CALL GDXXRW.EXE Inputs_Excel\Net_Trade.xls  o=GDXFiles\Net_Trade.gdx par=trade01 rng=sheet1!A1:F6  Rdim=1 Cdim=1
$GDXIN GDXFiles\Net_Trade.gdx
$LOAD trade01 = trade01
$GDXIN

*Transport costs parameters
                 transportcost1(i,j)    Initial matrix of transport costs from i to j (in USD per ton)
$CALL GDXXRW.EXE Inputs_Excel\Transport_costs.xls  o=GDXFiles\Transport_costs.gdx par=transportcost1 rng=sheet1!A1:F6  Rdim=1 Cdim=1
$GDXIN GDXFiles\Transport_costs.gdx
$LOAD transportcost1 = transportcost1
$GDXIN

Parameters
                avt(i,j)               Ad valorem tariffs between countries  (expressed as a pourcentage)
                sdt(i,j)               Specific tariffs between countries (in USD per ton)   ;

***Loads the ad valorem tariffs matrice or the specific tariffs matrice, depending on the option chosen at the beginning of the program
$If not setglobal tariffadvalorem avt(i,j)=0
$If not setglobal tariffadvalorem $goto skip1
$If not setglobal tariffspecific sdt(i,j)=0

$CALL GDXXRW.EXE Inputs_Excel\TariffsAV.xls  o=GDXFiles\TariffsAV.gdx par=avt rng=sheet1!A1:F6  Rdim=1 Cdim=1
$GDXIN GDXFiles\TariffsAV.gdx
$LOAD avt = avt
$GDXIN
$If not setglobal tariffspecific $goto skip2

$label skip1
$CALL GDXXRW.EXE Inputs_Excel\TariffsSD.xls  o=GDXFiles\TariffsSD.gdx par=sdt rng=sheet1!A1:F6  Rdim=1 Cdim=1
$GDXIN GDXFiles\TariffsSD.gdx
$LOAD sdt = sdt
$GDXIN
$label skip2

Parameters
*Additional parameters
                 prodprice1(i)          Initial producer price (in USD per ton)
$CALL GDXXRW.EXE Inputs_Excel\Prodprice.xls  o=GDXFiles\Prodprice.gdx par=prodprice1 rng=sheet1!A1:B5  Rdim=1
$GDXIN GDXFiles\Prodprice.gdx
$LOAD prodprice1 = prodprice1
$GDXIN
                 TTC0                   Initial total trade cost from i to j (in USD per ton)
                 e(i)                   Excess demand in i (in tons);

***Parameters definition
*We assume transport costs within the country (from i to i) are zero
transportcost1(i,i) =0;
TTC0 = sum{(i,j),{[transportcost1(i,j)+ sdt(i,j)$specific + (prodprice1(i)*avt(i,j))$advalorem]*trade01(i,j)}};
e(i) = sum[(j),trade01(j,i)-trade01(i,j)];

***Variables declaration
Variables
                 trade1(i,j)            Matrix of trade from i to j (in tons)
                 TTC                    Total trade cost from i to j (in USD per ton) ;
Positive variables
                 trade1 ;

***Variables initialization
trade1.l(i,j)    = trade01(i,j);
TTC.l            = TTC0;

***Equations declaration
Equations
                 Eq_TTC                 Equation of minimisation of the sum of total trade cost (Objective function)
                 Eq_Mkt(i)              Market equilibrium constraint ;

***Equations definition
Eq_TTC..                     sum{(i,j),[transportcost1(i,j)+ sdt(i,j)$specific + (prodprice1(i)*avt(i,j))$advalorem]*trade1(i,j)} =e= TTC ;
Eq_Mkt(i)..                  e(i) =e= sum[j,trade1(j,i)-trade1(i,j)]  ;

***Defines the model and determines the equations that are included in the model
Model Calibration1 Partial equilibrium model  /all/ ;

***Sets the memory space
Calibration1.workspace = 125 ;

***GAMS automatically scales the model and presents the results after reverse scaling to recover the original solution
Calibration1.scaleopt=1;

***Sets the number of decimal places to be included
OPTION DECIMALS=8;

***Chooses the solver. In this case the solver CONOPT is used. It is a solver for large-scale linear and nonlinear optimization.
OPTION LP = CONOPT;

***Solves the program, using Linear Programs
Solve Calibration1 MINIMIZING TTC USING LP;

***Declaration of parameters that will be used in the next step of the calibration: Calibration 2
Parameters
                 trade02(i,j)           Quantity exported from i to j after the first step of the calibration (in tons)
                 transportcost02(i,j)   Transport costs between i and j after the first step of the calibration (in USD per ton)
                 prodprice02(i)         Producer price in i after the first step of the calibration (in USD per ton) ;

***Definition of parameters that will be used in the next step of the calibration: Calibration 2
trade02(i,j) = trade1.l(i,j);
transportcost02(i,j) = transportcost1(i,j);
prodprice02(i) = prodprice1(i);



