*******************************************************************************
*                           Calibration: Step 2                               *
*******************************************************************************

***Parameters declaration
Parameters
*Parameters related to the initial objective function
                 wtc                      Weight associated with the transportation costs (depends on the degree of reliability of the data)
                 wp                       Weight associated with the market supply price (depends on the degree of reliability of the data)
*Parameters related to the price linkage equation
                 demand02(i)              Initial demand in i (in tons)
                 consprice02(i)           Initial consumer price in i (in USD per ton)
*Parameters related to the penalty function
                 mu                       Parameter for the complementary slackness condition
                 pi0(i,j)                 Initial price chain residual  (in USD per ton)
                 pen0                     Initial penalty  (in USD per ton)
*Parameters related to the new objective function
                 z0                       Initial objective function (without the penalty) (in USD per ton)
                 zz0                      Initial new objective function (including the penalty)(in USD per ton) ;

***Parameters definition
wtc                              = 1;
wp                               = 100;
demand02(j)                      = sum[i,trade02(i,j)];
consprice02(i)$trade02(i,i)      = prodprice02(i);
consprice02(i)$((trade02(i,i)=0) and (sum(j,trade02(j,i))>0)) = smin{j,prodprice02(j)+transportcost02(j,i)+ sdt(j,i)$specific
                                                                 + [(transportcost02(j,i)+prodprice02(j))*avt(j,i)]$advalorem
                                                                 - consprice02(i)} ;
mu                               = 0.0001;

*pi0 must be positive
pi0(i,j) = abs[transportcost02(i,j)+ sdt(i,j)$specific
         + [(transportcost02(i,j)+prodprice02(i))*avt(i,j)]$advalorem
         - consprice02(j)+ prodprice02(i)] ;

pen0     = mu*sum[(i,j),pi0(i,j)*trade02(i,j)];
z0       = wtc*sum{(i,j),power(transportcost02(i,j)-transportcost1(i,j),2)}+ wp*sum{i,power(prodprice02(i)-prodprice1(i),2)};
zz0      = z0+ pen0;

***Variables declaration
Variables
                 z                        Objective function (without the penalty) (in USD per ton)
                 zz                       New objective function (including the penalty)  (in USD per ton)

Positive variable
                 transportcost2(i,j)      Transportation costs from i to j (in USD per ton)
                 prodprice2(i)            Market supply price in i (in USD per ton)
                 consprice2(i)            Market demand price in i (in USD per ton)
                 pi(i,j)                  Price chain residual (in USD per ton)
                 pen                      Penalty (in USD per ton)
;

***Variables initialization
transportcost2.l(i,j)    = transportcost02(i,j);
prodprice2.l(i)          = prodprice02(i);
consprice2.l(i)          = consprice02 (i);
pi.l(i,j)                = pi0(i,j);
pen.l                    = pen0;
z.l                      = z0;
zz.l                     = zz0;

***Equations declaration
Equations
                 Eq_Obj                 Objective function (without the penalty)
                 Eq_PRLINK1(i,j)        Price linkeage equation 1
                 Eq_Pen                 Slackness condition
                 Eq_zz                  New objective function (including the penalty)
                 Eq_tc                  Transport costs on local sales should be zero
    ;

***Equations definition
Eq_Obj..                                z =e= wtc*sum{(i,j),power(transportcost2(i,j)-transportcost1(i,j),2)}+ wp*sum{i,power(prodprice2(i)-prodprice1(i),2)} ;
Eq_PRLINK1(i,j)..                       prodprice2(i) + transportcost2(i,j)+ sdt(i,j)$specific
                                        + [(transportcost2(i,j)+ prodprice2(i))*avt(i,j)]$advalorem =e= consprice2(j)+pi(i,j);
Eq_Pen..                                mu*sum[(i,j),pi(i,j)*trade02(i,j)] =e= pen ;
Eq_zz..                                 z+ pen =e= zz ;
Eq_tc(i)..                              transportcost2(i,i) =e= 0 ;

***Defines the model and determines the equations that are included in the model
Model Calibration2 Partial equilibrium model /all/;

***Sets the memory space
Calibration2.workspace = 125 ;

***GAMS automatically scales the model and presents the results after reverse scaling to recover the original solution
Calibration2.scaleopt=1;

***Sets the number of decimal places to be included
OPTION DECIMALS=8;

***This keyword controls the number of cases written to the LST file for each named equation in a model.
OPTION limcol=25;
OPTION limrow=25;

***Chooses the solver. In this case the solver CONOPT is used. It is a solver for large-scale nonlinear optimization
OPTION NLP = CONOPT;

***Progressively increases the value of mu to force the price chain residual to decrease to zero
***Solves the program Calibration2, using Non linear programs
while(( (pen.l/mu) ge 0.00000000001),
Solve Calibration2 MINIMIZING zz USING nlp;
mu = mu+0.00005 ;
) ;

***Declaration of parameters that will be used in scenarios A and B.
Parameter
                 transportcost03(i,j)   Bilateral transportation costs after the second step of the calibration (in USD per ton)
                 prodprice03(i)         Market supply price after the second step of the calibration  (in USD per ton)
                 consprice03(i)         Market demand price after the second step of the calibration (in USD per ton) ;

***Defintion of parameters that will be used in scenarios A and B.
transportcost03(i,j) = transportcost2.l(i,j);
prodprice03(i) = prodprice2.l(i);
consprice03(i) = consprice2.l(i);

